import { serve } from "https://deno.land/std@0.90.0/http/server.ts";
import { renderFileToString } from "https://deno.land/x/dejs@0.9.3/mod.ts";
import { getAccessToken, getProfileInfo } from "./google_login_api.js";

// get api keys
const settings = JSON.parse(await Deno.readTextFile("settings.json"));

// urlencode OAuth login url
let google_oauth_url = new URL('https://accounts.google.com/o/oauth2/v2/auth');
google_oauth_url.searchParams.set('scope', 'https://www.googleapis.com/auth/userinfo.profile https://www.googleapis.com/auth/userinfo.email');
google_oauth_url.searchParams.set('redirect_uri', settings.redirect_url);
google_oauth_url.searchParams.set('response_type', 'code');
google_oauth_url.searchParams.set('client_id', settings.client_id);
google_oauth_url.searchParams.set('access_type', 'online');
google_oauth_url = google_oauth_url.toString();

const server = serve({ hostname: '0.0.0.0', port: 8080 });
console.log('HTTP webserver running. Access it at: http://localhost:8080/');

for await (const request of server) {
    let request_url = new URL(request.url, 'http://localhost:8080');
   
    switch(request_url.pathname) {
    	case '/':
    		let html = await renderFileToString('views/index.html', { google_oauth_url: google_oauth_url });
    		request.respond({ status: 200, body: html });
    		break;

    	case '/google-auth':
    		try {
    			let access_token = await getAccessToken(settings.client_id, settings.client_secret, settings.redirect_url, request_url.searchParams.get('code'));
    			let profile_info = await getProfileInfo(access_token);
    			
    			let html = await renderFileToString('views/google-auth.html', { profile_info: profile_info });
	    		request.respond({ status: 200, body: html });
    		}
			catch(error) {
				let html = await renderFileToString('views/google-auth.html', { error: error.message });
	    		request.respond({ status: 200, body: html });
			}

    		break;
    }
}